# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec
%{!?dotests: %define dotests 1}

%global __tar /opt/freeware/bin/tar
%global name tlog
%global version 13
%global release 1
%global _libdir64 %{_libdir}64


Summary:    Terminal I/O logger
Name:       %{name}
Version:    %{version}
Release:    %{release}
License:    GPL-2.0-or-later
Group:      Applications/System
URL:        https://github.com/Scribery/%{name}
Source0:    %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz

Patch1:     0001-code-changes-for-aix-support.patch


BuildRequires:  autoconf >= 2.71
BuildRequires:  automake >= 1.16.5
BuildRequires:  libtool >= 2.4.7
BuildRequires:  m4 >= 1.4.19
BuildRequires:  make >= 4.4.1
BuildRequires:  json-c-devel >= 0.15
BuildRequires:  curl-devel >= 8.4.0

%if %{toolchain} == "gcc"
Requires: libgcc >= 10
%endif
Requires:  json-c >= 0.15
Requires:  curl >= 8.5.0

%description
Tlog is a terminal I/O recording program similar to "script", but used in
place of a user's shell, starting the recording and executing the real user's
shell afterwards. The recorded I/O can then be forwarded to a logging server
in JSON format.

%prep
%setup -n %{name}-%{version}
%patch1 -p1


rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit


%build
# Building 64 bit version
cd 64bit
export OBJECT_MODE=64
export CC="%{__cc__} -maix64 -pthread"
export CFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include"
export CXX="%{__cxx__} -maix64 -pthread"
export CXXFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include"
export LDFLAGS="-s -L/opt/freeware/lib/pthread -L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/lib"

autoreconf -i -f

./configure \
	--prefix=%{_prefix} \
	--disable-journal \
	--disable-static \
	--mandir=%{_mandir}\
	--docdir=%{_defaultdocdir}/%{name}-%{version} \
	--libdir=%{_libdir64}
make V=1

# Building 32 bit version
cd ../32bit

export OBJECT_MODE=32
export CC="%{__cc__} -maix32 -pthread"
export CFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include"
export CXX="%{__cxx__} -maix32 -pthread"
export CXXFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include"
export LDFLAGS="-s -L/opt/freeware/lib/pthread -L/opt/freeware/lib -L/usr/lib"

autoreconf -i -f

./configure \
        --prefix=%{_prefix} \
        --disable-journal \
        --disable-static \
        --mandir=%{_mandir}\
        --docdir=%{_defaultdocdir}/%{name}-%{version} \
        --libdir=%{_libdir}
make V=1

%install
cd 64bit
make DESTDIR=$RPM_BUILD_ROOT install prefix=%{_prefix} 
rm %{buildroot}/%{_libdir64}/*.la

# Rename executables
for f in ${RPM_BUILD_ROOT}%{_bindir}/* ; do
    mv ${f} ${f}_64
done

# Create the lock dir
mkdir -p %{buildroot}%{_localstatedir}/run
install -d -m 0755 %{buildroot}%{_localstatedir}/run/%{name}

cd ../32bit
make DESTDIR=$RPM_BUILD_ROOT install prefix=%{_prefix} 
rm %{buildroot}/%{_libdir}/*.la

#Rename executables and make 64bit as default.
(
cd  ${RPM_BUILD_ROOT}/%{_prefix}/bin
for f in $(ls -1| grep -v -e _32 -e _64); do
    mv ${f} ${f}_32
    ln -sf "$f"_64 $f
done
)

#Extract 64 bit so from archive 64bit library and archive into 32bit library
cd ${RPM_BUILD_ROOT}%{_libdir64}
/usr/bin/ar -x -X64 libtlog.a
cd ${RPM_BUILD_ROOT}%{_libdir}
/usr/bin/ar -q -X64 libtlog.a  ${RPM_BUILD_ROOT}%{_libdir64}/libtlog.so.0

%check
cd 64bit
if [ "%{dotests}" == 1 ]
then
    ( ulimit -m unlimited; ulimit -d unlimited;gmake -k check || true )
    /usr/sbin/slibclean
fi

cd ../32bit
if [ "%{dotests}" == 1 ]
then
    ( ulimit -m unlimited; ulimit -d unlimited;gmake -k check || true )
    /usr/sbin/slibclean
fi


%files
%defattr(-,root,system)
%doc 32bit/COPYING 
%{_bindir}/*
%{_libdir}/*.a
%{_libdir64}/*.a
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_datadir}/%{name}
%{_sysconfdir}/*
%{_defaultdocdir}/%{name}-%{version}/*
%dir %{_localstatedir}/run/%{name}


%changelog
* Tue Jan 30 2024 Ranjit Ranjan  <ranjit.ranjan@ibm.com> 13-1
- Port on AIX 


